# -*- coding: utf-8 -*-
"""
Plot functions for MCS_052_main.py.

@author: silvan.schwebke
"""

import matplotlib.pyplot as plt
from numpy import hstack, zeros
import os

def data_distribution(data,numBins):
    fig = plt.figure()
    ax = fig.add_subplot(111)
    ax.hist(data,numBins,color='green',alpha=0.8)
    plt.show()
    
#plt.subplots(figsize=plt.figaspect(0.4))

def doubleplot_k_ratio_volfrac(kL,kT,u_rel_kL,u_rel_kT,volfrac,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    fig, ax = plt.subplots(211)
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(volfrac, kL, yerr=z*u_rel_kL*kL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(volfrac, kT, yerr=z*u_rel_kT*kT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    ax.set_xlim([min(volfrac)-0.02,max(volfrac)+0.02])
    ax.set_ylim([0.0,max(hstack((kL,kT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Metal fraction in vol%")
    ax.set_ylabel("k (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    ax.text(0.0, -0.17, string,
        verticalalignment='bottom', horizontalalignment='left',
        transform=ax.transAxes, color='black', fontsize=12)
    plt.tight_layout(pad=1.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/k_plot_volfrac.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/k_plot_volfrac'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def k_plot_volfrac(kL,kT,u_rel_kL,u_rel_kT,volfrac,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    fig, ax = plt.subplots()
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(volfrac, kL, yerr=z*u_rel_kL*kL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(volfrac, kT, yerr=z*u_rel_kT*kT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    ax.set_xlim([min(volfrac)-0.02,max(volfrac)+0.02])
    ax.set_ylim([0.0,max(hstack((kL,kT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Metal fraction in vol%")
    ax.set_ylabel("k (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    ax.text(0.0, -0.17, string,
        verticalalignment='bottom', horizontalalignment='left',
        transform=ax.transAxes, color='black', fontsize=12)
    plt.tight_layout(pad=1.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/k_plot_volfrac.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/k_plot_volfrac'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def k_plot_molefrac(kL,kT,u_rel_kL,u_rel_kT,molefrac,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    fig, ax = plt.subplots()
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(molefrac, kL, yerr=z*u_rel_kL*kL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(molefrac, kT, yerr=z*u_rel_kT*kT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    ax.set_xlim([min(molefrac)-0.02,max(molefrac)+0.02])
    ax.set_ylim([0.0,max(hstack((kL,kT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Metal fraction in at%")
    ax.set_ylabel("k (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    ax.text(0.0, -0.17, string,
        verticalalignment='bottom', horizontalalignment='left',
        transform=ax.transAxes, color='black', fontsize=12)
    plt.tight_layout(pad=1.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/k_plot_molefrac.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/k_plot_molefrac'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def R_plot_molefrac(R,u_rel_R,molefrac,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    fig, ax = plt.subplots()
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(molefrac, R, yerr=z*u_rel_R*R, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.set_yscale('log')
    ax.set_xlim([min(molefrac)-0.02,max(molefrac)+0.02])
    #ax.set_ylim([0.0,max(R)*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Metal fraction in at%")
    ax.set_ylabel("$\mathsf{R_0}$ (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    ax.text(0.0, -0.17, string,
        verticalalignment='bottom', horizontalalignment='left',
        transform=ax.transAxes, color='black', fontsize=12)
    plt.tight_layout(pad=1.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/R_plot_molefrac.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/R_plot_molefrac'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def k_ratio_plot_molefrac(kL,kT,u_rel_kL,u_rel_kT,molefrac,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    k_ratio = zeros(len(kL))
    u_abs_k_ratio = zeros((2,len(kL)))
    for i in range(len(kL)):
        k_ratio[i] = kT[i]/kL[i]
        u_abs_k_ratio[0,i]= abs(kT[i]/kL[i]*u_rel_kL[0,i]) + abs(1./kL[i]*u_rel_kT[0,i]*kT[i])
        u_abs_k_ratio[1,i]= abs(kT[i]/kL[i]*u_rel_kL[1,i]) + abs(1./kL[i]*u_rel_kT[1,i]*kT[i])
    fig, ax = plt.subplots()
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(molefrac, k_ratio, yerr=z*u_abs_k_ratio, marker='s', label='$\mathrm{\mathsf{k_T/k_L}}$')
    ax.set_xlim([min(molefrac)-0.02,max(molefrac)+0.02])
    ax.set_ylim([0.0,1.0])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Metal fraction in at%")
    ax.set_ylabel("Transversal sensitivity $\mathrm{\mathsf{k_T/k_L}}$")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    ax.text(0.0, -0.17, string,
        verticalalignment='bottom', horizontalalignment='left',
        transform=ax.transAxes, color='black', fontsize=12)
    plt.tight_layout(pad=1.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/k_ratio_plot_molefrac.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/k_ratio_plot_molefrac'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def k_plot_dist(kL,kT,u_rel_kL,u_rel_kT,dist,string,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 18}
#    matplotlib.rc('font', **font)
#    matplotlib.rcParams['axes.formatter.use_locale'] = True
    fig, ax = plt.subplots()
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(dist, kL, yerr=z*u_rel_kL*kL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(dist, kT, yerr=z*u_rel_kT*kT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    #ax.set_xlim([min(dist)-0.1,max(dist)+0.1])
    ax.set_ylim([0.0,max(hstack((kL,kT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("mean particle distance s in nm "+string)
    ax.set_ylabel("k (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='upper right',numpoints=1)
    plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/k_plot_dist.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/k_plot_dist'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')

def k_plot_deformation(kL,kT,u_rel_kL,u_rel_kT,deformation,save_to_folder=False):
    fig, ax = plt.subplots()
    strain = zeros(len(deformation))
    for i in range(len(deformation)):
        strain[i] = 1000.*(deformation[i]-1.0)
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(strain, kL, yerr=z*u_rel_kL*kL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(strain, kT, yerr=z*u_rel_kT*kT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    ax.set_xlim([min(strain)-0.3,max(strain)+0.3])
    ax.set_ylim([0.0,max(hstack((kL,kT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Strain in per mill")
    ax.set_ylabel("k (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='lower right',numpoints=1)
    plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        cnt = 1
        filename = save_to_folder + '/k_plot_deformation' + str(cnt) + '.png'
        filename_other = save_to_folder + '/otherplotformats/k_plot_deformation' + str(cnt)
        while os.path.exists(filename):
            filename = save_to_folder + '/k_plot_deformation' + str(cnt) + '.png'
            filename_other = save_to_folder + '/otherplotformats/k_plot_deformation' + str(cnt)
            cnt = cnt + 1
        fig.savefig(filename, format='png')
        fig.savefig(filename_other+'.eps', format='eps')
        fig.savefig(filename_other+'.pdf', format='pdf')
        fig.savefig(filename_other+'.svg', format='svg')

def k_ratio_plot_deformation(kL,kT,u_rel_kL,u_rel_kT,deformation,save_to_folder=False):
    fig, ax = plt.subplots()
    k_ratio = zeros(len(kL))
    u_abs_k_ratio = zeros((2,len(kL)))
    for i in range(len(kL)):
        k_ratio[i] = kT[i]/kL[i]
        u_abs_k_ratio[0,i]= abs(kT[i]/kL[i]*u_rel_kL[0,i]) + abs(1./kL[i]*u_rel_kT[0,i]*kT[i])
        u_abs_k_ratio[1,i]= abs(kT[i]/kL[i]*u_rel_kL[1,i]) + abs(1./kL[i]*u_rel_kT[1,i]*kT[i])
    strain = zeros(len(deformation))
    for i in range(len(deformation)):
        strain[i] = 1000.*(deformation[i]-1.0)
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(strain, k_ratio, yerr=z*u_abs_k_ratio, marker='s', label='$\mathrm{\mathsf{k_T/k_L}}$')
    ax.set_xlim([min(strain)-0.3,max(strain)+0.3])
    ax.set_ylim([0.0,1.0])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Strain in per mill")
    ax.set_ylabel("Transversal sensitivity $\mathrm{\mathsf{k_T/k_L}}$")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='lower right',numpoints=1)
    plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        cnt = 1
        filename = save_to_folder + '/k_ratio_plot_deformation' + str(cnt) + '.png'
        filename_other = save_to_folder + '/otherplotformats/k_ratio_plot_deformation' + str(cnt)
        while os.path.exists(filename):
            filename = save_to_folder + '/k_ratio_plot_deformation' + str(cnt) + '.png'
            filename_other = save_to_folder + '/otherplotformats/k_ratio_plot_deformation' + str(cnt)
            cnt = cnt + 1
        fig.savefig(filename, format='png')
        fig.savefig(filename_other+'.eps', format='eps')
        fig.savefig(filename_other+'.pdf', format='pdf')
        fig.savefig(filename_other+'.svg', format='svg')

def R_plot_deformation(RL,RT,u_rel_RL,u_rel_RT,deformation,save_to_folder=False):
#    font = {'family' : 'sans-serif',
#        'weight' : 'normal',
#        'size'   : 30}
    #matplotlib.rc('font', **font)
    fig, ax = plt.subplots()
    strain = zeros(len(deformation))
    for i in range(len(deformation)):
        strain[i] = 1000.*(deformation[i]-1.0)
    z = 1.96  # statistische Abweichung (wie viele sigma)
    ax.errorbar(strain, RL, yerr=z*u_rel_RL*RL, marker='s', label='$\mathrm{\mathsf{k_L}}$')
    ax.errorbar(strain, RT, yerr=z*u_rel_RT*RT, marker='D', label='$\mathrm{\mathsf{k_T}}$')
    ax.set_xlim([min(strain)-0.3,max(strain)+0.3])
    #ax.set_ylim([0.0,max(hstack((RL,RT)))*1.2])
    #plt.xticks([0.2, 0.3, 0.4, 0.5])
    ax.set_xlabel("Strain in per mill")
    ax.set_ylabel("$\mathsf{R_0}$ (Simulation)")
    handles, labels = ax.get_legend_handles_labels()
    # remove the errorbars for the legend
    handles = [h[0] for h in handles]
    # use them in the legend
    ax.legend(handles, labels, loc='lower right',numpoints=1)
    plt.tight_layout(pad=0.4, w_pad=0.5, h_pad=1.0)
    plt.show()
    if save_to_folder:
        filename = save_to_folder + '/R_plot_deformation.png'
        fig.savefig(filename, format='png')
        filename = save_to_folder + '/otherplotformats/R_plot_deformation'
        fig.savefig(filename+'.eps', format='eps')
        fig.savefig(filename+'.pdf', format='pdf')
        fig.savefig(filename+'.svg', format='svg')
